@@ -2,7 +2,7 @@ import tkstyle
 from cyberpunk_theme import constant
 
 
-def get_style():
+def get_style(**kwargs):
     style = tkstyle.PanedWindow()
-    style.background = constant.COLOR_BLACK
+    style.background = constant.BACKGROUND_COLOR
     return style
